package model

import (
	"game/server/login/config"
	"github.com/fox/fox/db"
	"github.com/fox/fox/log"
	"github.com/go-redis/redis/v8"
	"gorm.io/gorm"
)

var (
	UserRedis *redis.Client
	UserDB    *gorm.DB
	LogDB     *gorm.DB
)

func InitRedis() {
	var err error
	cfg := &config.Cfg.Redis
	UserRedis, err = db.InitRedis(cfg.Password, cfg.Host, cfg.Port, 0)
	if err != nil {
		log.Fatal(err.Error())
		return
	}
}

func InitDb() {
	var err error
	cfg := &config.Cfg.Mysql
	UserDB, err = db.InitMysql(cfg.Username, cfg.Password, cfg.Host, cfg.Port, cfg.DbName)
	if err != nil {
		log.Fatal(err.Error())
		return
	}
	cfg = &config.Cfg.MysqlLog
	LogDB, err = db.InitMysql(cfg.Username, cfg.Password, cfg.Host, cfg.Port, cfg.DbName)
	if err != nil {
		log.Fatal(err.Error())
		return
	}
	// 自动迁移game库表结构
	err = UserDB.AutoMigrate(
		&UserAccount{},
	)
	if err != nil {
		log.Fatal(err.Error())
		return
	}
	// 自动迁移game_log库表结构
	err = LogDB.AutoMigrate(
		&UserLoginLog{},
	)
	if err != nil {
		log.Fatal(err.Error())
		return
	}
}
